@@ -405,7 +405,8 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
             # Compute prediction on eval and test set
             eval_prediction = self.sub_predict(self.X[eval_slice])
             self.y_eval[eval_slice] = eval_prediction
-            test_prediction = self.sub_predict(self.X[test_slice])
+            predictors = self.X[test_slice]
+            test_prediction = self.sub_predict(predictors)
             self.y_test[test_slice] = test_prediction
 
             ev = self.y_eval[eval_slice]
@@ -439,7 +440,7 @@ class RollMultiLayerPerceptron(MultiLayerPerceptron, roller._RollingBasis):
 
         self.last_eval_slice = eval_slice
         self.last_test_slice = test_slice
-        return eval_slice, test_slice
+        return eval_slice, test_slice, predictors, tt, tt_true
 
     def unroll_features(self, dates, feature_names, display_slices = False, gradient = False):
         self.handle_callback('begin_fit')
