@@ -6,17 +6,17 @@ import sqlite3
 from multiprocessing import Pool
 from napoleontoolbox.file_saver import dropbox_file_saver
 
+import json
 
 class SignalParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', lookback_windows=[5], thresholds=[1.], contravariants=[1.]):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', signal_idiosyncratic_paramaters=[None]):
         self.args = []
         self.counter = 1
         self.seed = 0
-        for w in lookback_windows:
-            for t in thresholds:
-                for c in contravariants:
-                    self.args.append((self,self.seed,w,t,c))
-                    self.counter = self.counter + 1
+        for signal_type, params  in signal_idiosyncratic_paramaters.items():
+            for param in params:
+                self.args.append((self,self.seed,signal_type,json.dumps(param, sort_keys=True)))
+                self.counter = self.counter + 1
         self.args.sort()
         self.local_root_directory = local_root_directory
         self.user = user
